@@ -1,2 +1,2 @@
 from .sample import Sample, SampleCreate, SampleUpdate
-from .run import Run, RunCreate, RunUpdate
+from .trace import Trace, TraceCreate, TraceUpdate
